@@ -7,17 +7,23 @@ import re
 import subprocess
 
 from derrick.core.detector import Detector
+from derrick.core.logger import Logger
 
 default_image = "openjdk"
-default_version = "latest"
+default_version = "8"
 regex = r"(?!\.)(\d+(\.\d+)+)([-.][A-Z]+)?(?![\d.])"
 
 
 class JavaVersionDetector(Detector):
     def execute(self):
         print("Detecting Java version ...")
-        output = subprocess.check_output(["java", "-version"], shell=False, stderr=subprocess.STDOUT)
-        version = JavaVersionDetector.get_most_relative_version(output)
+        version = default_version;
+        try:
+            output = subprocess.check_output(["java", "-version"], shell=False, stderr=subprocess.STDOUT)
+            version = JavaVersionDetector.get_most_relative_version(output)
+        except Exception as e:
+            Logger.debug("Failed to detect Java version,because of %s" % e)
+            Logger.debug("Use default Java version:%s instead ." % default_version)
         return {"version": version}
 
     @staticmethod
