@@ -6,10 +6,15 @@ from __future__ import absolute_import, division, print_function
 import unittest
 from derrick.core.command_manager import CommandManager
 from derrick.core.command import Command
+from derrick.core.derrick import Derrick
 
 
 class CommandManagerTestCase(unittest.TestCase):
     def setUp(self):
+        # pre load
+        derrick = Derrick()
+        derrick.load()
+
         self.cm = CommandManager()
         self.cm.load()
 
@@ -19,7 +24,7 @@ class CommandManagerTestCase(unittest.TestCase):
 
     def test_built_in_commands_registered(self):
         commands_dict = self.cm.all()
-        self.assertIsNot(None, commands_dict["build"])
+        self.assertIsNot(None, commands_dict["up"])
         self.assertIsNot(None, commands_dict["init"])
 
     def test_built_int_commands_re_registration(self):
